@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,100 +24,67 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/Fl.H>
-#include "core/channels/sampleChannel.h"
-#include "core/const.h"
-#include "core/model/model.h"
-#include "core/wave.h"
-#include "core/mixer.h"
-#include "core/recorder.h"
-#include "core/recManager.h"
-#include "utils/string.h"
-#include "utils/fs.h"
+#include "sampleChannelButton.h"
 #include "glue/channel.h"
 #include "gui/dialogs/mainWindow.h"
-#include "sampleChannel.h"
 #include "keyboard.h"
-#include "sampleChannelButton.h"
+#include "sampleChannel.h"
+#include "utils/fs.h"
+#include "utils/string.h"
+#include <FL/Fl.H>
 
-
-extern giada::v::gdMainWindow* G_MainWin;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-geSampleChannelButton::geSampleChannelButton(int x, int y, int w, int h, ID channelId)
-: geChannelButton(x, y, w, h, channelId)
+geSampleChannelButton::geSampleChannelButton(int x, int y, int w, int h, const c::channel::Data& d)
+: geChannelButton(x, y, w, h, d)
 {
-	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
+	switch (m_channel.getPlayStatus())
 	{
-		const m::SampleChannel& sc = static_cast<m::SampleChannel&>(c);
-		
-		switch (sc.playStatus) {
-			case ChannelStatus::EMPTY:
-				label("-- no sample --");
-				break;
-			case ChannelStatus::MISSING:
-			case ChannelStatus::WRONG:
-				label("* file not found! *");
-				break;
-			default:
-				if (sc.name.empty()) {
-					m::model::onGet(m::model::waves, sc.waveId, [&](m::Wave& w)
-					{
-						label(w.getBasename(false).c_str());
-					});
-				}
-				else
-					label(sc.name.c_str());
-				break;
-		}
-	});
+	case ChannelStatus::MISSING:
+	case ChannelStatus::WRONG:
+		label("* file not found! *");
+		break;
+	default:
+		label(m_channel.sample->waveId == 0 ? "-- no sample --" : m_channel.name.c_str());
+		break;
+	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geSampleChannelButton::refresh()
 {
 	geChannelButton::refresh();
-	
-	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
-	{
-		if (m::recManager::isRecordingInput() && c.armed)
-			setInputRecordMode();
-		else
-		if (m::recManager::isRecordingAction() && c.hasData())
-			setActionRecordMode();
-	});
+
+	if (m_channel.isRecordingInput() && m_channel.isArmed())
+		setInputRecordMode();
+	else if (m_channel.isRecordingAction() && m_channel.sample->waveId != 0 && !m_channel.sample->isLoop)
+		setActionRecordMode();
 
 	redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geSampleChannelButton::handle(int e)
 {
 	int ret = geButton::handle(e);
-	switch (e) {
-		case FL_DND_ENTER:
-		case FL_DND_DRAG:
-		case FL_DND_RELEASE: {
-			ret = 1;
-			break;
-		}
-		case FL_PASTE: {
-			c::channel::loadChannel(m_channelId, u::string::trim(u::fs::stripFileUrl(Fl::event_text())));
-			ret = 1;
-			break;
-		}
+	switch (e)
+	{
+	case FL_DND_ENTER:
+	case FL_DND_DRAG:
+	case FL_DND_RELEASE:
+	{
+		ret = 1;
+		break;
+	}
+	case FL_PASTE:
+	{
+		c::channel::loadChannel(m_channel.id, u::string::trim(u::fs::stripFileUrl(Fl::event_text())));
+		ret = 1;
+		break;
+	}
 	}
 	return ret;
 }
-
-}} // giada::v::
+} // namespace giada::v
